@@ -26,8 +26,9 @@ module TestUnitTestUtil
     yield(test) if block_given?
     suite = Test::Unit::TestSuite.new(test_case.name, test_case)
     suite << test
-    runner_class.run_all_tests do |run_context|
-      suite.run(result, run_context: run_context) {}
+    runner_class.run_all_tests(result, {test_suite: suite}) do |run_context|
+      worker_context = Test::Unit::WorkerContext.new(nil, run_context, result)
+      suite.run(worker_context) {}
     end
     result
   end
